How to get help with the floatThead
------------
**I just had a kid, and I work at a startup,**  
I don't have time to reproduce your issue on my own, so please provide a **jsfiddle!!!**

----
All issues should be reported through github. If you don't have an account you can make one.  
 - Search previous issues to see if there is a resolution to your issue already. For common problems see: https://github.com/mkoryak/floatThead/issues/91
 
Providing the following will greatly increase the chances of your issue being resolved quickly:

 - Give me: browser version, OS version, jQuery version, floatThead version if not latest
 - Provide a jsfiddle that reproduces your issue in its simplest form possible [required]
 - A description of the issue and steps to reproduce
 

I will put in as much effort into helping you as you put in describing your problem / creating fiddle.

Pull requests
-----

Pull requests are welcome. Please create your pull request against master and make modifications to `jquery.floatThead.js` 
in the project root, not in `/dist`  

If you have grunt and can build your changes into dist by running `grunt` - that would be super, but if not, ill do it, no big deal.  

Changes landing on master will not be released on bower (as a new version) until there is a big enough critical mass of new features, or if 
a critical bug gets fixed, or if you buy me a beer ;)  

I would rather not add any new options to the API, if you would like to add an option think about a way that the same thing can be accomplished with feature detection or by overloading an existing option.  

Thanks for reading, and may the force be with you and your cat.

